#!/usr/bin/env python3
#! -*- coding:utf8 -*-
"""The script change a file md table to excel
"""
import os  
import sys
import chardet
import pyexcel as pe
from xlrd.biffh import XLRDError
from app.helpers.reading_params import get_argument

def check_path_is_file(file_input):
  """check the file in put as md and file excel is not exit"""
  if os.path.isfile(file_input.name ):  
    return True
  else:  
    print("Not a file!")
    return False

def _main(argv=get_argument()):
  """Main executer"""
  try:
    sheet = pe.get_book(file_name=argv.file_input.name)
    print(sheet)
  except pe.exceptions.FileTypeNotSupported:
    print("FileTypeNotSupported!")
  except XLRDError as e:
    print(e)
  except UnicodeDecodeError:
    # import pdb; pdb.set_trace()
    encoding = chardet.detect(open(argv.file_input.name, 'rb').read()).get('encoding')
    sheet = pe.get_book(file_name=argv.file_input.name, encoding=encoding)
    print(sheet)
  except IOError as e:
    print(e.message)
    
if __name__ == '__main__':
    _main()


#!/usr/bin/env python3
#! -*- coding:utf-8 -*-
""" Helper get argument of scripts
"""

import argparse
import os


__parser__ = argparse.ArgumentParser(description='input')
__parser__.add_argument(
    action='store',
    dest='file_input',
    type=open,
    metavar="FILE",
    help="The input FILE xls"
)
# __parser__.add_argument(
#     '-i', '--input',
#     action='store',
#     dest='file_input',
#     type=open,
#     metavar="FILE",
#     help="The input FILE"
# )
# __parser__.add_argument(
#     '-o', '--output',
#     action='store',
#     dest='file_output',
#     metavar="FILE",
#     help="The output FILE "
# )


def get_argument():
    """return argument  """
    args = __parser__.parse_args()
    return args



#!/usr/bin/env python3
#!-*-coding:utf8-*-
"""File setup.py"""
from setuptools import setup, find_packages
setup(
    name='catxls',
    version='0.0.4',
    packages=find_packages(
        '.',
        exclude=[
            '*.tests', '*.tests.*', 'tests.*', 'tests'
        ]
    ),
    license='MIT',
    description='read xls, xlsx on server',
    author='huongnhd',
    author_email = 'huong.nhdh@gmail.com',
    url = 'https://github.com/huongnhdh/catxls.git',
    download_url = 'https://github.com/huongnhdh/catxls/archive/v_003.tar.gz',
    keywords = ['xls', 'xlsx', 'cat xlsx', 'server'],
    install_requires=[
      'pyexcel==0.5.13',
      'pyexcel-xls==0.5.8',
      'chardet==3.0.4'
    ],
    classifiers=[
    'Development Status :: 4 - Beta',
    'Intended Audience :: System Administrators',
    'Topic :: System :: System Shells',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 2',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
    entry_points="""
    [console_scripts]
    catxls=app.scripts.catxlsx:_main
    """
)
